@@ -2,14 +2,17 @@
 Easy to use python subprocess interface.
 '''
 
+import ConfigParser
 import logging
+import os.path
 import platform
 import shlex
 import subprocess
 import tempfile
 import time
 
-__version__ = '0.0.3'
+
+__version__ = '0.0.4'
 
 log = logging.getLogger(__name__)
 #log=logging
@@ -19,6 +22,8 @@ log.debug('version=' + __version__)
 # deadlock test fails if USE_FILES=0
 USE_FILES = 1
 
+CONFIG_FILE = '~/.easyprocess.cfg'
+
 class EasyProcessError(Exception):
     """  
     """
@@ -26,25 +31,10 @@ class EasyProcessError(Exception):
         self.easy_process = easy_process
         self.msg = msg
     def __str__(self):
-        msg = self.msg + '( Exception( {typ}={detail} ) , Process(cmd={cmd} returncode={return_code} stderr="{stderr}"))'.format(
-                            cmd=self.easy_process.cmd,
-                            typ=type(self.easy_process.detail),
-                            detail=self.easy_process.detail,
-                            return_code=self.easy_process.return_code,
-                            stderr=self.easy_process.stderr,
-                            )
-        return msg
+        return self.msg + ' ' + repr(self.easy_process)
     
-#class EasyProcessCheckError(EasyProcessError):
-#    """This exception is raised when a process run by check() returns
-#    a non-zero exit status or OSError is raised.  
-#    """
-#    def __init__(self, easy_process):
-#        msg = 'EasyProcess check failed!'
-#        EasyProcessError.__init__(self, easy_process, msg)
-
 template = '''cmd={cmd}
-OSError={detail}  
+OSError={oserror}  
 Program install error! '''
 class EasyProcessCheckInstalledError(Exception):
     """This exception is raised when a process run by check() returns
@@ -54,7 +44,7 @@ class EasyProcessCheckInstalledError(Exception):
         self.easy_process = easy_process
     def __str__(self):
         msg = template.format(cmd=self.easy_process.cmd,
-                          detail=self.easy_process.detail,
+                          oserror=self.easy_process.oserror,
                           )
         if self.easy_process.url:
             msg += '\nhome page: ' + self.easy_process.url
@@ -71,6 +61,7 @@ class Proc():
     shell is not supported (shell=False)
     
     '''
+    config = None
     
     def __init__(self, cmd, ubuntu_package=None, url=None):
         '''
@@ -84,7 +75,8 @@ class Proc():
         self.url = url
         self.ubuntu_package = ubuntu_package
         self.is_started = False
-        self.detail = None
+        self.oserror = None
+        self.cmd_param = cmd
 
         if hasattr(cmd, '__iter__'):
             # cmd is string list
@@ -95,7 +87,40 @@ class Proc():
             self.cmd = shlex.split(cmd)
             self.cmd_as_string = cmd
         log.debug('command: %s (%s)' % (str(self.cmd), self.cmd_as_string))
+        if not len(cmd):
+            raise EasyProcessError(self, 'empty command!')
+        
+        if not Proc.config:
+            conf_file = os.path.expanduser(CONFIG_FILE)
+            log.debug('reading config: %s' % (conf_file))
+            Proc.config = ConfigParser.RawConfigParser()
+            Proc.config.read(conf_file)
+        
+        self.alias = None
+        try:
+            self.alias = Proc.config.get('path', self.cmd[0])
+        except ConfigParser.NoSectionError:
+            pass
+        except ConfigParser.NoOptionError:
+            pass
+        
+        if self.alias:
+            log.debug('alias found: %s' % (self.alias))
+            self.cmd[0] = self.alias
 
+    def __repr__(self):
+        msg = '<{cls} cmd_param={cmd_param} alias={alias} cmd={cmd} ({scmd}) oserror={oserror} returncode={return_code} stdout="{stdout}" stderr="{stderr}">'.format(
+                            cls=self.__class__.__name__,
+                            cmd_param=self.cmd_param,
+                            cmd=self.cmd,
+                            oserror=self.oserror,
+                            alias=self.alias,
+                            return_code=self.return_code,
+                            stderr=self.stderr,
+                            stdout=self.stdout,
+                            scmd=' '.join(self.cmd),
+                            )
+        return msg
         
     @property
     def pid(self):
@@ -126,15 +151,18 @@ class Proc():
         :param return_code: int, expected return code
         :rtype: self
         '''
-        try:
-            ret = self.call().return_code
-            ok = ret == return_code
-        except OSError as detail:
-            log.debug('OSError exception')
-            ok = False
-            self.detail = detail
+#        try:
+#            ret = self.call().return_code
+#            ok = ret == return_code
+#        except Exception as e:
+#            log.debug('OSError exception:' + str(oserror))
+#            ok = False
+#            self.oserror = oserror
+
+        ret = self.call().return_code
+        ok = ret == return_code
         if not ok:
-            raise EasyProcessError(self)
+            raise EasyProcessError(self, 'check error, return code is not zero!')
         return self
 
     def check_installed(self):
@@ -150,9 +178,9 @@ class Proc():
         '''
         try:
             self.call()
-        except Exception as detail:
-            log.debug('OSError exception')
-            self.detail = detail
+        except Exception as e:
+            #log.debug('exception:' + str(e))
+            #self.oserror = oserror
             raise EasyProcessCheckInstalledError(self)
         return self
     
@@ -177,8 +205,6 @@ class Proc():
         if USE_FILES:
             self._stdout_file = tempfile.NamedTemporaryFile(prefix='stdout')
             self._stderr_file = tempfile.NamedTemporaryFile(prefix='stderr')
-            #self._stdout_file = open('/tmp/stdout','w+')
-            #self._stderr_file = open('/tmp/stderr','w+')
             stdout = self._stdout_file
             stderr = self._stderr_file
             
@@ -192,8 +218,9 @@ class Proc():
                                   stderr=stderr,
                                   #shell=1,
                                   )
-        except Exception, e:
-            self.detail = e
+        except OSError, oserror:
+            log.debug('OSError exception:' + str(oserror))
+            self.oserror = oserror
             raise EasyProcessError(self, 'start error')
         
         log.debug('process was started (pid=%s)' % (str(self.pid),))
@@ -312,21 +339,13 @@ class Proc():
             x = None
             try:     
                 x = callable()
-            except Exception, e:
-                self.detail = e
-                msg = 'wrap error, Process(cmd={cmd}({scmd}) returncode={return_code} stderr="{stderr}"))'.format(
-                                    cmd=self.cmd,
-                                    scmd=' '.join(self.cmd),
-                                    return_code=self.return_code,
-                                    stderr=self.stderr,
-                                    )
-                print msg
-                raise
+            except OSError, oserror:
+                log.debug('OSError exception:' + str(oserror))
+                self.oserror = oserror
+                raise EasyProcessError(self, 'wrap error!')
             finally:
                 self.stop()
             return x
         return wrapped
 
-EasyProcess=Proc
-
-
+EasyProcess = Proc
